#!/bin/bash

set -x
set -u
set -e

PKGNAME=perl-5.20.1.1

BUILDSCRIPT=$(readlink -f $0)
BASEDIR=$(dirname $BUILDSCRIPT)
BUILDDIR=$BASEDIR/$PKGNAME
TARGETDIR=$BUILDDIR/target/$PKGNAME


if [ ! -e $BASEDIR/strawberry-perl-5.20.1.1-32bit.zip ]; then
	(cd $BASEDIR; wget http://strawberryperl.com/download/5.20.1.1/strawberry-perl-5.20.1.1-32bit.zip)
fi
if [ "x$(sha1sum $BASEDIR/strawberry-perl-5.20.1.1-32bit.zip | sed -e 's/ .*$//')" != "x8125e015b27a6b83fe8e0d302d6c4acaea675256" ]; then
	exit 1
fi

#The source isn't embedded in the strawberry perl package - we include the build script and the patches it references
SOURCE_AND_PATCHES="
https://raw.githubusercontent.com/StrawberryPerl/Perl-Dist-Strawberry/a1ae6818e75d5b65b4fc5b2db4d1eba0ff320501/share/64bit-5.20.1.1.pp|8adb6d154c0c1b13288dd537a50594e3c60acee9
http://www.cpan.org/src/5.0/perl-5.20.1.tar.bz2|cd424d1520ba2686fe5d4422565aaf880e9467f6
https://raw.githubusercontent.com/StrawberryPerl/Perl-Dist-Strawberry/d61496c34854bc2e3fb734c4bb6dc830ebe6ec0e/share/perl-5.20/diffs_for_info_only/perl5-maint-5.20_installperl.diff|167178595cb42eb3868412bfe15368005a44d110
https://raw.githubusercontent.com/StrawberryPerl/Perl-Dist-Strawberry/d61496c34854bc2e3fb734c4bb6dc830ebe6ec0e/share/perl-5.20/diffs_for_info_only/perl5-maint-5.20_win32_FindExt.pm.diff|071e9926d105f0bb408f61184a38f57f91008547
https://raw.githubusercontent.com/StrawberryPerl/Perl-Dist-Strawberry/d61496c34854bc2e3fb734c4bb6dc830ebe6ec0e/share/perl-5.20/diffs_for_info_only/perl5-maint-5.20_win32_config.gc.diff|7f81ba76c6096d4402d80ac88fd3f90698842b4d
https://raw.githubusercontent.com/StrawberryPerl/Perl-Dist-Strawberry/d61496c34854bc2e3fb734c4bb6dc830ebe6ec0e/share/perl-5.20/diffs_for_info_only/perl5-maint-5.20_win32_config_H.gc.diff|c2c505fd2eb2e140889a5a8b3200c036af20d735
https://raw.githubusercontent.com/StrawberryPerl/Perl-Dist-Strawberry/d61496c34854bc2e3fb734c4bb6dc830ebe6ec0e/share/perl-5.20/diffs_for_info_only/perl5-maint-5.20_win32_perlexe.rc.diff|e6dc28b2087c5838bab6bef6030a1346be0e3eee
https://raw.githubusercontent.com/StrawberryPerl/Perl-Dist-Strawberry/d61496c34854bc2e3fb734c4bb6dc830ebe6ec0e/share/perl-5.20/diffs_for_info_only/perl5-maint-5.20_win32_win32.h.diff|d822a41d4f08cffb6c3536cd07773c698309d607
"
SOURCES_TO_DIST=""

for SP in $SOURCE_AND_PATCHES; do
	OLD_IFS=$IFS
	IFS='|'
	SPLAT=($SP)
	FILENAME=$(basename "${SPLAT[0]}")
	if [ ! -e $BASEDIR/$FILENAME ]; then
		wget ${SPLAT[0]}
	fi
	if [ "x$(sha1sum $BASEDIR/$FILENAME | sed -e 's/ .*$//')" != "x${SPLAT[1]}" ]; then
		echo "Checksum for $FILENAME doesn't match."
		exit 1
	fi
	SOURCES_TO_DIST="$SOURCES_TO_DIST $BASEDIR/$FILENAME"
	IFS=$OLD_IFS
done

rm -rf $BUILDDIR
mkdir $BUILDDIR

cd $BUILDDIR
unzip $BASEDIR/strawberry-perl-5.20.1.1-32bit.zip "perl/lib/CORE/*" -d $BUILDDIR/vanilla

mkdir -p $TARGETDIR/lib
cp -R $BUILDDIR/vanilla/perl/lib/CORE $TARGETDIR/lib/

mkdir $TARGETDIR/src
cp $BUILDSCRIPT $SOURCES_TO_DIST $TARGETDIR/src

(cd $TARGETDIR/..; tar czf $BUILDDIR/$PKGNAME.tar.gz $PKGNAME)
#gpg -ab $BUILDDIR/$PKGNAME.tar.gz
#gpg --verify $BUILDDIR/$PKGNAME.tar.gz.asc

rm -rf /devel/pidgin-devel/win32-dev/$PKGNAME
cp -R $TARGETDIR /devel/pidgin-devel/win32-dev/

